@@ -94,6 +94,7 @@ def pseudo_binary(content_type):
     content_type = content_type.lower()
     return (content_type.startswith('text/')
             or content_type.endswith('+xml')
+            or content_type.endswith('+json')
             or content_type == 'application/javascript'
             or content_type == 'application/json')
 
@@ -133,7 +134,8 @@ def std_error_message(message):
         try:
             print >> sys.stderr, message
         except UnicodeDecodeError:
-            print >> sys.stderr, 'cannot display message due to mismatching terminal character encoding'
+            print >> sys.stderr, ('cannot display message due to '
+                    'mismatching terminal character encoding')
 
 
 def superclass_name(instance):
